# Supported Models

The vLLM Spyre plugin relies on model code implemented by the [Foundation Model Stack](https://github.com/foundation-model-stack/foundation-model-stack/tree/main/fms/models).

| Model Family | Supported |
| ------------ | --------- |
| Granite      | ✅        |
| LLaMA        | ✅        |
| RoBERTa      | ✅        |
